@@ -104,6 +104,7 @@ class Map:
     size: str
     custom: bool
     seed: int
+    mod_id: int
     zr: bool
     modes: dict
     tiles: list
@@ -179,6 +180,9 @@ class Match:
     build_version: int
     timestamp: datetime
     spec_delay: timedelta
+    allow_specs: bool
+    hidden_civs: bool
+    private: bool
     hash: str
     actions: list
     inputs: list
