@@ -316,7 +316,7 @@ class FullSummary: # pylint: disable=too-many-public-methods
         if self._header.hd:
             return self._header.hd.selected_map_id
         if self._header.de:
-            return self._header.de.selected_map_id
+            return self._header.de.resolved_map_id
         return self._header.scenario.game_settings.map_id
 
     def get_map(self):
@@ -332,7 +332,7 @@ class FullSummary: # pylint: disable=too-many-public-methods
                 self.reference,
                 tiles,
                 de_seed=self._header.lobby.de.map_seed if self._header.lobby.de else None,
-                de_strings=self._header.de.strings if self._header.de else []
+                de_strings=self._header.de.rms_strings.strings if self._header.de else []
             )
         return self._cache['map']
 
